@@ -1,6 +1,6 @@
 #
 #		tktext.rb - Tk text classes
-#			$Date: 1999/01/20 04:59:34 $
+#			$Date: 1999/04/26 09:42:43 $
 #			by Yukihiro Matsumoto <matz@caelum.co.jp>
 
 require 'tk.rb'
@@ -247,11 +247,11 @@ class TkText<TkTextWin
   private :_tag_bind_core
 
   def tag_bind(tag, seq, cmd=Proc.new, args=nil)
-    _tag_bind_core('', tag, seq, cmd=Proc.new, args=nil)
+    _tag_bind_core('', tag, seq, cmd, args=nil)
   end
 
   def tag_bind_append(tag, seq, cmd=Proc.new, args=nil)
-    _tag_bind_core('+', tag, seq, cmd=Proc.new, args=nil)
+    _tag_bind_core('+', tag, seq, cmd, args=nil)
   end
 
   def tag_bindinfo(tag, context=nil)
