@@ -3,7 +3,7 @@
   io.c -
 
   $Author: matz $
-  $Date: 1999/05/12 05:27:32 $
+  $Date: 1999/05/18 06:06:12 $
   created at: Fri Oct 15 18:08:59 JST 1993
 
   Copyright (C) 1993-1999 Yukihiro Matsumoto
@@ -2163,7 +2163,7 @@ next_argv()
 		}
 		file = prep_stdio(fr, FMODE_READABLE, rb_cFile);
 	    }
-	    rb_io_binmode(file);
+	    if (binmode) rb_io_binmode(file);
 	}
 	else {
 	    init_p = 0;
