@@ -1,6 +1,6 @@
 #
 #		thread.rb - thread support classes
-#			$Date: 1999/03/24 08:52:35 $
+#			$Date: 1999/04/16 06:03:36 $
 #			by Yukihiro Matsumoto <matz@caelum.co.jp>
 #
 
@@ -120,6 +120,7 @@ class Queue
     Thread.critical = false
     t.run if t
   end
+  alias enq push
 
   def pop non_block=false
     Thread.critical = true
@@ -139,6 +140,8 @@ class Queue
       Thread.critical = false
     end
   end
+  alias shift pop
+  alias deq pop
 
   def empty?
     @que.length == 0
