@@ -3,7 +3,7 @@
   range.c -
 
   $Author: matz $
-  $Date: 1999/05/10 08:22:45 $
+  $Date: 1999/05/17 09:54:14 $
   created at: Thu Aug 19 17:46:47 JST 1993
 
   Copyright (C) 1993-1999 Yukihiro Matsumoto
@@ -189,7 +189,7 @@ rb_range_beg_len(range, begp, lenp, len, err)
 	beg += len;
 	if (beg < 0) goto out_of_range;
     }
-    if (err == 2) {
+    if (err == 0 || err == 2) {
 	if (beg > len) goto out_of_range;
 	if (end > len || (!EXCL(range) && end == len))
 	    goto out_of_range;
@@ -197,7 +197,7 @@ rb_range_beg_len(range, begp, lenp, len, err)
     if (end < 0) {
 	end += len;
 	if (end < 0) {
-	    if (err == 1 && e == -1 && !EXCL(range)) {
+	    if (beg == 0 && end == -1 && !EXCL(range)) {
 		len = 0;
 		goto length_set;
 	    }
