@@ -3,7 +3,7 @@
   ruby.c -
 
   $Author: matz $
-  $Date: 1999/04/30 07:55:46 $
+  $Date: 1999/05/18 06:06:16 $
   created at: Tue Aug 10 12:47:31 JST 1993
 
   Copyright (C) 1993-1999 Yukihiro Matsumoto
@@ -191,7 +191,7 @@ addpath(path)
 #if defined(__CYGWIN32__)
     {
 	char rubylib[FILENAME_MAX];
-	conv_to_posix_path(path, rubylib);
+	conv_to_posix_path(path, rubylib, FILENAME_MAX);
 	path = rubylib;
     }
 #endif
@@ -203,7 +203,7 @@ addpath(path)
 	while (*p) {
 	    while (*p == sep) p++;
 	    if (s = strchr(p, sep)) {
-		rb_ary_push(ary, rb_str_new2(rubylib_mangle(p, (int)(s-p))));
+		rb_ary_push(ary, rb_str_new(rubylib_mangle(p, (int)(s-p)), (int)(s-p)));
 		p = s + 1;
 	    }
 	    else {
