@@ -3,7 +3,7 @@
   signal.c -
 
   $Author: matz $
-  $Date: 1999/04/09 17:57:43 $
+  $Date: 1999/05/10 08:22:47 $
   created at: Tue Dec 20 10:13:44 JST 1994
 
 ************************************************/
@@ -312,7 +312,6 @@ signal_exec(sig)
 	    break;
 #ifndef NT
 	  case SIGHUP:
-	  case SIGTERM:
 #endif
 #ifdef SIGPIPE
 	  case SIGPIPE:
@@ -497,7 +496,6 @@ trap(arg)
 	  case SIGINT:
 #ifndef NT
 	  case SIGHUP:
-	  case SIGTERM:
 #endif
 #ifdef SIGQUIT
 	  case SIGQUIT:
@@ -615,7 +613,6 @@ Init_signal()
     ruby_signal(SIGINT, sighandle);
 #ifndef NT
     ruby_signal(SIGHUP, sighandle);
-    ruby_signal(SIGTERM, sighandle);
 #endif
 #ifdef SIGPIPE
     ruby_signal(SIGPIPE, sighandle);
