@@ -3,7 +3,7 @@
   string.c -
 
   $Author: matz $
-  $Date: 1999/05/13 10:01:07 $
+  $Date: 1999/05/17 09:54:17 $
   created at: Mon Aug  9 17:12:58 JST 1993
 
   Copyright (C) 1993-1999 Yukihiro Matsumoto
@@ -701,7 +701,7 @@ rb_str_succ(orig)
 {
     VALUE str, str2;
     char *sbeg, *s;
-    char c = -1;
+    int c = -1;
 
     str = rb_str_new(RSTRING(orig)->ptr, RSTRING(orig)->len);
 
@@ -1708,7 +1708,7 @@ tr_trans(str, src, repl, sflag)
 	}
     }
     else {
-	char r;
+	int r;
 
 	for (i=0; i<256; i++) {
 	    trans[i] = 0;
