@@ -3,7 +3,7 @@
   time.c -
 
   $Author: matz $
-  $Date: 1999/04/16 10:12:06 $
+  $Date: 1999/05/14 08:56:12 $
   created at: Tue Dec 28 14:31:59 JST 1993
 
   Copyright (C) 1993-1999 Yukihiro Matsumoto
@@ -944,7 +944,7 @@ time_load(klass, str)
     }
 
     if ((p & (1<<31)) == 0) {
-	return time_new_internal(klass, sec, usec);
+	return time_new_internal(klass, p, s);
     }
     p &= ~(1<<31);
     tm.tm_year = (p >> 14) & 0x1ffff;
